# kema
> :wrench: A tool for helping setting up projects

## :rocket: Getting Started

These instructions will get you a copy of the project up and running on your
local machine for development and testing purposes.

### :inbox_tray: Prerequisites

The following software is required to be installed on your system:

- [Python](https://www.python.org/downloads/)

### :package: Installation

You can install the program in your computer for your own use.

```
pip install kema
```

### :video_game: Usage

After you have installed the program you can run it from everywhere. Just run
`kema`.

```
kema generate <module_name>
```

Use `--help` for more help on usage.

### :hammer: Development

Setup the project and all dependencies for development.

```bash
. bin/setup
```

Run the tests.

```
bin/test
```

Format the code accordingly to common guide lines.

```
bin/format
```

Lint your python code.

```
bin/lint
```

Publish the application to [PyPI](https://pypi.org/project/kema/).

```
bin/publish
```

